@@ -51,3 +51,7 @@ class objearth():
         
         else:
             print("Nonetype :",type(self.DataArray))
+    
+    def mosaic(self):
+        product = self.DataArray.max(dim="time",skipna=True)
+        return product
